@@ -579,7 +579,7 @@ class LoggerReporter(BaseReporter):
             keyword = VERSION_COMMAND
             # remove redundant version from strings since these are already 
             # identified as version information
-            format_output=lambda x: x.replace("Version:","").replace(", version","")
+            format_output=lambda x: x.replace("Version:","").replace(", version","").split("/")[-1]
             for line in lines:
                 if keyword in line:
                     data[format_output(line.split(keyword)[-1].strip())]=1
@@ -594,7 +594,7 @@ class LoggerReporter(BaseReporter):
         children = self.run_context.dag.successors(task_no)
         parents = self.run_context.dag.predecessors(task_no)
         msg = " {} parents: {}.  {} children: {}."
-        return msg.format(len(parents), parents, len(children), children)
+        return msg.format(len(list(parents)), parents, len(list(children)), children)
     
     def log_event(self, msg, task_no, debug_msg=None):
         visible=self.run_context.tasks[task_no].visible
